;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "clojure-mode" "20250527.840"
  "Major mode for Clojure code."
  '((emacs "25.1"))
  :url "https://github.com/clojure-emacs/clojure-mode"
  :commit "d336db623e7ae8cffff50aaaea3f1b05cc4ccecb"
  :revdesc "d336db623e7a"
  :keywords '("languages" "clojure" "clojurescript" "lisp")
  :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
